@@ -1352,7 +1352,7 @@ install_recently_played_menu (AisleriotWindow *window)
     char actionname[32];
     char *game_name, *tooltip;
 
-    g_snprintf (actionname, sizeof (actionname), "Recent%d", i);
+    g_snprintf (actionname, sizeof (actionname), "Recent%"G_GSIZE_FORMAT, i);
     game_name = games_filename_to_display_name (recent_games[i]);
 #ifdef HAVE_HILDON
     tooltip = NULL;
@@ -1849,7 +1849,11 @@ game_exception_response_cb (GtkWidget *dialog,
 
     g_snprintf (pidstr, sizeof (pidstr), "%d", getpid ());
 
+#if GTK_CHECK_VERSION (2, 91, 8)
+    if (!g_spawn_async (
+#else
     if (!gdk_spawn_on_screen (gtk_widget_get_screen (GTK_WIDGET (window)),
+#endif
                               NULL /* working dir */,
                               (char **) argv,
                               NULL /* envp */,
