@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from defaults import *
 
 try:
@@ -73,13 +74,16 @@ _defaults = {'show_toolbar':                     True,
              'show_history':                     True,
              'maximised':                        False,
              'fullscreen':                       False,
+             'piece_style':                      'simple',
              'show_3d':                          False,
+             'show_3d_smooth':                   False,             
              'show_move_hints':                  True,
              'move_format':                      'human',
              'promotion_type':                   'queen',
              'board_view':                       'human',
              'show_comments':                    False,
              'show_numbering':                   False,
+             'show_captured_pieces':             False,
              'enable_networking':                True,
              'load_directory':                   '',
              'save_directory':                   '',
@@ -139,10 +143,11 @@ def set(name, value):
             function = _gconfSetFunction[type(value)]
         except KeyError:
             raise TypeError('Only config values of type: int, str, float, bool supported')
-        except gobject.GError:
-            pass
         else:
-            function(_GCONF_DIR + name, value)
+            try:
+                function(_GCONF_DIR + name, value)
+            except gobject.GError:
+                pass
 
     else:
         # Debounce
@@ -186,19 +191,14 @@ def watch(name, function):
         try:
             watchers = _notifiers[name]
         except KeyError:
-            watchers = []
-            
+            watchers = _notifiers[name] = []            
         watchers.append(function)
-            
-        _notifiers[name] = watchers
 
 def _save():
     """Save the current configuration"""
     if haveGConfSupport:
         return
     
-    import xml.dom.minidom
-    
     document = xml.dom.minidom.Document()
     
     e = document.createComment('Automatically generated by glChess, do not edit!')
