@@ -15,7 +15,7 @@ import chess.board
 
 class MovePlayer(game.ChessPlayer):
     """This class provides a pseudo-player to watch for piece movements"""
-    
+
     def __init__(self, view):
         """Constructor for a move player.
         
@@ -46,14 +46,12 @@ class MovePlayer(game.ChessPlayer):
 class CairoPiece(scene.ChessPieceFeedback):
     """
     """
-    
-    model = None
-    
-    location = ''
-    
+
     def __init__(self, scene, piece):
         self.scene = scene
         self.piece = piece
+        self.model = None
+        self.location = ''
 
     def onDeleted(self):
         """Called by scene.ChessPieceFeedback"""
@@ -66,16 +64,6 @@ class CairoPiece(scene.ChessPieceFeedback):
 class SceneCairo(scene.SceneFeedback, scene.human.SceneHumanInput):
     """
     """
-    controller = None
-    
-    # The game this scene is rendering
-    game = None
-    
-    # TODO
-    pieces       = None
-    
-    # FIXME: Abort when scenes changed
-    waitingPiece = None
 
     def __init__(self, view):
         """
@@ -84,11 +72,24 @@ class SceneCairo(scene.SceneFeedback, scene.human.SceneHumanInput):
         self.controller = scene.cairo.Scene(self)
         self.game = view.game
         self.pieces = {}
+        self.waitingPiece = None
         scene.human.SceneHumanInput.__init__(self)
         
     def getPieces(self):
         return self.pieces.values()
 
+    def addPiece(self, piece, location, captured = False):
+        pieceName = {chess.board.PAWN: 'pawn', chess.board.ROOK: 'rook', chess.board.KNIGHT: 'knight',
+                     chess.board.BISHOP: 'bishop', chess.board.QUEEN: 'queen', chess.board.KING: 'king'}[piece.getType()]
+        chessSet = {chess.board.WHITE: 'white', chess.board.BLACK: 'black'}[piece.getColour()]
+        p = CairoPiece(self, piece)
+        style = config.get('piece_style')
+        p.model = self.controller.addChessPiece(chessSet, pieceName, location, p, style=style, captured=captured)
+        p.location = location
+        if not captured:
+            self.pieces[piece] = p
+        return p
+
     def movePiece(self, piece, location, delete, animate):
         """
         """
@@ -97,12 +98,7 @@ class SceneCairo(scene.SceneFeedback, scene.human.SceneHumanInput):
             p = self.pieces[piece]
         except KeyError:
             # Make the new model
-            pieceName = {chess.board.PAWN: 'pawn', chess.board.ROOK: 'rook', chess.board.KNIGHT: 'knight',
-                         chess.board.BISHOP: 'bishop', chess.board.QUEEN: 'queen', chess.board.KING: 'king'}[piece.getType()]
-            chessSet = {chess.board.WHITE: 'white', chess.board.BLACK: 'black'}[piece.getColour()]
-            p = CairoPiece(self, piece)
-            p.model = self.controller.addChessPiece(chessSet, pieceName, location, p)
-            self.pieces[piece] = p
+            p = self.addPiece(piece, location)
 
         # Move the model
         p.location = location
@@ -110,6 +106,11 @@ class SceneCairo(scene.SceneFeedback, scene.human.SceneHumanInput):
         
         return p
 
+    def clearCapturedPieces(self):
+        """
+        """
+        self.controller.clearCapturedPieces()
+
     # Extended methods
 
     def onRedraw(self):
@@ -148,14 +149,12 @@ class SceneCairo(scene.SceneFeedback, scene.human.SceneHumanInput):
 class OpenGLPiece(scene.ChessPieceFeedback):
     """
     """
-    
-    model = None
-    
-    location = ''
-    
+
     def __init__(self, scene, piece):
         self.scene = scene
         self.piece = piece
+        self.model = None
+        self.location = ''
 
     def onDeleted(self):
         """Called by scene.ChessPieceFeedback"""
@@ -167,15 +166,7 @@ class OpenGLPiece(scene.ChessPieceFeedback):
 
 class SceneOpenGL(scene.SceneFeedback, scene.human.SceneHumanInput):
     """
-    """
-    # The game this scene is rendering
-    game          = None
-    
-    # TODO
-    pieces        = None
-    
-    # FIXME: Abort when scenes changed
-    waitingPiece = None
+    """   
 
     def __init__(self, view):
         """Constructor for a glChess scene.
@@ -185,6 +176,7 @@ class SceneOpenGL(scene.SceneFeedback, scene.human.SceneHumanInput):
         self.view = view
         self.game = view.game
         self.pieces = {}
+        self.waitingPiece = None
 
         # Call parent constructors
         self.controller = scene.opengl.Scene(self)
@@ -193,6 +185,17 @@ class SceneOpenGL(scene.SceneFeedback, scene.human.SceneHumanInput):
     def getPieces(self):
         return self.pieces.values()
         
+    def addPiece(self, piece, location, captured = False):
+        pieceName = {chess.board.PAWN: 'pawn', chess.board.ROOK: 'rook', chess.board.KNIGHT: 'knight',
+                     chess.board.BISHOP: 'bishop', chess.board.QUEEN: 'queen', chess.board.KING: 'king'}[piece.getType()]
+        chessSet = {chess.board.WHITE: 'white', chess.board.BLACK: 'black'}[piece.getColour()]
+        p = OpenGLPiece(self, piece)
+        p.model = self.controller.addChessPiece(chessSet, pieceName, location, p, captured=captured)
+        p.location = location
+        if not captured:
+            self.pieces[piece] = p
+        return p
+
     def movePiece(self, piece, location, delete, animate):
         """
         """
@@ -201,12 +204,7 @@ class SceneOpenGL(scene.SceneFeedback, scene.human.SceneHumanInput):
             p = self.pieces[piece]
         except KeyError:
             # Make the new model
-            pieceName = {chess.board.PAWN: 'pawn', chess.board.ROOK: 'rook', chess.board.KNIGHT: 'knight',
-                         chess.board.BISHOP: 'bishop', chess.board.QUEEN: 'queen', chess.board.KING: 'king'}[piece.getType()]
-            chessSet = {chess.board.WHITE: 'white', chess.board.BLACK: 'black'}[piece.getColour()]
-            p = OpenGLPiece(self, piece)
-            p.model = self.controller.addChessPiece(chessSet, pieceName, location, p)
-            self.pieces[piece] = p
+            p = self.addPiece(piece, location)
             
         # Move the model
         p.location = location
@@ -214,6 +212,11 @@ class SceneOpenGL(scene.SceneFeedback, scene.human.SceneHumanInput):
 
         return p
 
+    def clearCapturedPieces(self):
+        """
+        """
+        self.controller.clearCapturedPieces()
+
     # Extended methods
 
     def onRedraw(self):
@@ -251,10 +254,8 @@ class SceneOpenGL(scene.SceneFeedback, scene.human.SceneHumanInput):
 
 class Splashscreen(ui.ViewFeedback):
     """
-    """    
-    application = None
-    scene       = None
-    
+    """
+
     def __init__(self, application):
         """Constructor.
         
@@ -283,17 +284,22 @@ class Splashscreen(ui.ViewFeedback):
         self.scene.showBoardNumbering(showNumbering)
         self.cairoScene.showBoardNumbering(showNumbering)
 
+    def showCapturedPieces(self, showCaptured):
+        """Called by ui.ViewFeedback"""
+        self.scene.controller.showCapturedPieces(showCaptured)
+        self.cairoScene.controller.showCapturedPieces(showCaptured)
+
     def showMoveHints(self, showHints):
         """Called by ui.ViewFeedback"""
         pass
 
-    def renderGL(self):
+    def renderGL(self, background_colour = (0, 0, 0)):
         """Called by ui.ViewFeedback"""
-        self.scene.render()
+        self.scene.render(background_colour)
         
-    def renderCairoStatic(self, context):
+    def renderCairoStatic(self, context, background_color = (0, 0, 0)):
         """Called by ui.ViewFeedback"""
-        return self.cairoScene.renderStatic(context)
+        return self.cairoScene.renderStatic(context, background_color)
         
     def renderCairoDynamic(self, context):
         """Called by ui.ViewFeedback"""
@@ -332,9 +338,7 @@ class Splashscreen(ui.ViewFeedback):
 class View(ui.ViewFeedback):
     """
     """
-    # The controller object for this view
-    controller  = None
-    
+
     def __init__(self, game):
         """Constructor.
         
@@ -349,15 +353,20 @@ class View(ui.ViewFeedback):
         self.selectedCoord = None
         self.showHints = False
         self.showNumbering = False
+        self.showCaptured = False
         self.doSmooth = False
         self.highlightParams = (None, None, None, None)
         self.changedHighlight = True
         
+        self.controller  = None
+        
         # Use a Cairo scene by default - it will be replaced by an OpenGL one if that is the requested view
         # I wanted to remove this but then scene is None and there are a number of issues...
         # This should be cleaned up
         self.scene = SceneCairo(self)
         config.watch('board_view', self.__onBoardViewChanged)
+        config.watch('piece_style', self.__onPiecesStyleChanged)
+        config.watch('show_captured_pieces', self.__onShowCapturedPiecesChanged)
 
         # Look for game events to update the scene
         movePlayer = MovePlayer(self)
@@ -377,6 +386,12 @@ class View(ui.ViewFeedback):
     def __onBoardViewChanged(self, key, value):
         self.updateRotation()
 
+    def __onPiecesStyleChanged(self, key, value):
+        self.updatePiecesStyle()
+
+    def __onShowCapturedPiecesChanged(self, key, value):
+        self.showCapturedPieces(value)
+
     def _updateHighlight(self, coord):
         if self.moveNumber == -1:
             player = self.game.getCurrentPlayer()
@@ -441,6 +456,10 @@ class View(ui.ViewFeedback):
 
         self.scene.controller.setBoardRotation(rotation, boardView == 'facetoface', animate)
 
+    def updatePiecesStyle(self):
+        piecesStyle = config.get('piece_style')
+        self.scene.controller.setPiecesStyle(piecesStyle)
+    
     def _pieceMoved(self, piece):
         """
         """
@@ -460,6 +479,11 @@ class View(ui.ViewFeedback):
         """Called by ui.ViewFeedback"""
         self.showNumbering = showNumbering
         self.scene.controller.showBoardNumbering(showNumbering)
+
+    def showCapturedPieces(self, showCaptured):
+        """Called by ui.ViewFeedback and __onShowCapturedPiecesChanged"""
+        self.showCaptured = showCaptured
+        self.scene.controller.showCapturedPieces(showCaptured)
         
     def showSmooth(self, doSmooth):
         """Called by ui.ViewFeedback"""
@@ -480,18 +504,19 @@ class View(ui.ViewFeedback):
         self.reshape(self.width, self.height)
         self.setMoveNumber(self.moveNumber)
         self.showBoardNumbering(self.showNumbering)
+        self.showCapturedPieces(self.showCaptured)
         self.showSmooth(self.doSmooth)
         self.updateRotation(animate = False)
 
-    def renderGL(self):
+    def renderGL(self, background_colour = (0, 0, 0)):
         """Called by ui.ViewFeedback"""
         self.updateScene(SceneOpenGL)
-        self.scene.controller.render()
+        self.scene.controller.render(background_colour)
 
-    def renderCairoStatic(self, context):
+    def renderCairoStatic(self, context, background_color = (0, 0, 0)):
         """Called by ui.ViewFeedback"""
         self.updateScene(SceneCairo)
-        return self.scene.controller.renderStatic(context)
+        return self.scene.controller.renderStatic(context, background_color)
         
     def renderCairoDynamic(self, context):
         """Called by ui.ViewFeedback"""
@@ -511,6 +536,40 @@ class View(ui.ViewFeedback):
     def deselect(self, x, y):
         """Called by ui.ViewFeedback"""
         self.scene.deselect(x, y)
+        
+    __capturedTypeSortOrder = [
+        chess.board.QUEEN,  chess.board.ROOK, chess.board.BISHOP,
+        chess.board.KNIGHT, chess.board.PAWN
+        ]
+
+    @classmethod
+    def __capturedPieceTypeKey(cls, piece):
+        return cls.__capturedTypeSortOrder.index(piece.getType())
+    
+    @classmethod
+    def __getCapturedPieceLocations(cls, pieces):
+        whitePiece = 0
+        blackPiece = 0
+        
+        pieceLocations = {}
+        
+        # Sort captured pieces by type.
+        for piece in sorted(pieces, key = cls.__capturedPieceTypeKey):
+            if piece.getColour() == chess.board.WHITE:
+                # Captured white pieces go near black's queenside: files
+                # 'a' and 'b' (starting at 'b'), rank 8 to rank 1.
+                rank = ['a', 'b'][(whitePiece + 1) % 2]
+                file = 8 - (whitePiece / 2)
+                whitePiece += 1
+            else:
+                # Captured black pieces go near white's kingside: files
+                # 'g' and 'h' (starting at 'g'), rank 1 to rank 8.
+                rank = ['g', 'h'][blackPiece % 2]
+                file = 1 + (blackPiece / 2)
+                blackPiece += 1
+            pieceLocations[piece] = "%s%s" % (rank, file)
+
+        return pieceLocations
     
     def setMoveNumber(self, moveNumber):
         """Called by ui.ViewFeedback"""
@@ -533,6 +592,12 @@ class View(ui.ViewFeedback):
         # Move the models in the scene
         for (location, piece) in piecesByLocation.iteritems():
             self.scene.movePiece(piece, location, False, True)
+        
+        # Handle captured pieces
+        capturedPieceLocations = self.__getCapturedPieceLocations(self.game.getDeadPieces(moveNumber))
+        self.scene.clearCapturedPieces()
+        for (piece, location) in capturedPieceLocations.iteritems():
+            self.scene.addPiece(piece, location, captured = True)
 
         # Can't wait for animation if not looking at the latest move
         if moveNumber != -1:
