@@ -91,14 +91,24 @@ class GtkNewGameDialog:
 
         # Load the UI
         self.__gui = gtkui.loadUIFile('new_game.ui')
-        self.__gui.connect_signals(self)
 
         self.window = self.__gui.get_object('new_game_dialog')
         self.window.set_transient_for(mainUI.mainWindow)
 
-        # Set style of error panel
-        mainUI.setTooltipStyle(self.__gui.get_object('info_box'))
-        
+        self.infobar = gtk.InfoBar()
+        self.window.get_content_area().pack_start(self.infobar, False, True, 0)
+        vbox = gtk.VBox()
+        self.infobar.add(vbox)
+        vbox.show()
+        self.infoTitleLabel = gtk.Label()
+        vbox.pack_start(self.infoTitleLabel, False, True, 0)
+        self.infoTitleLabel.show()
+        self.infoDescriptionLabel = gtk.Label()
+        vbox.pack_start(self.infoDescriptionLabel, False, True, 0);
+        self.infoDescriptionLabel.show()
+
+        self.__gui.connect_signals(self)
+
         # Make all the labels the same width
         group = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
         i = 1
@@ -261,9 +271,9 @@ class GtkNewGameDialog:
         # Display warning if missing the AIs
         if len(errors) > 0:
             # Translators: New Game Dialog: Title of error box when loaded game had AI engines missing
-            self.__gui.get_object('info_title_label').set_markup('<big><b>%s</b></big>' % _('Game settings changed'))
-            self.__gui.get_object('info_description_label').set_markup('<i>%s</i>' % '\n'.join(errors))
-            self.__gui.get_object('info_box').show()
+            self.infoTitleLabel.set_markup('<big><b>%s</b></big>' % _('Game settings changed'))
+            self.infoDescriptionLabel.set_markup('<i>%s</i>' % '\n'.join(errors))
+            self.infobar.get_object('info_box').show()
 
         # Show the dialog
         self.window.present()
@@ -420,14 +430,24 @@ class GtkLoadGameDialog:
         
         # Load the UI
         self.__gui = gtkui.loadUIFile('load_game.ui')
-        self.__gui.connect_signals(self)
-        
+
         self.window = self.__gui.get_object('game_load_dialog')
         self.window.set_transient_for(mainUI.mainWindow)
-        
-        # Set style of error panel
-        mainUI.setTooltipStyle(self.__gui.get_object('error_box'))
-        
+
+        self.infobar = gtk.InfoBar()
+        self.window.get_content_area().pack_start(self.infobar, False, True, 0)
+        vbox = gtk.VBox()
+        self.infobar.add(vbox)
+        vbox.show()
+        self.infoTitleLabel = gtk.Label()
+        vbox.pack_start(self.infoTitleLabel, False, True, 0)
+        self.infoTitleLabel.show()
+        self.infoDescriptionLabel = gtk.Label()
+        vbox.pack_start(self.infoDescriptionLabel, False, True, 0);
+        self.infoDescriptionLabel.show()
+
+        self.__gui.connect_signals(self)
+
         fileChooser = self.__gui.get_object('filechooserwidget')
         
         try:
@@ -474,10 +494,11 @@ class GtkLoadGameDialog:
 
             if error is not None:
                 self.firstExpose = True
-                self.__gui.get_object('error_box').show()
+                self.infobar.set_message_type(gtk.MESSAGE_ERROR)
                 # Translators: Title of error box when unable to load game
-                self.__gui.get_object('error_title_label').set_markup('<big><b>%s</b></big>' % _('Unabled to load game'))
-                self.__gui.get_object('error_description_label').set_markup('<i>%s</i>' % error)
+                self.infoTitleLabel.set_markup('<big><b>%s</b></big>' % _('Unabled to load game'))
+                self.infoDescriptionLabel.set_markup('<i>%s</i>' % error)
+                self.infobar.show()
                 return
 
         dialog.destroy()
@@ -496,13 +517,24 @@ class GtkSaveGameDialog:
         
         # Load the UI
         self.__gui = gtkui.loadUIFile('save_game.ui')
-        self.__gui.connect_signals(self)
-        
-        # Set style of error panel
-        mainUI.setTooltipStyle(self.__gui.get_object('error_box'))
 
         self.window = self.__gui.get_object('save_dialog')
         self.window.set_transient_for(mainUI.mainWindow)
+        
+        self.infobar = gtk.InfoBar()
+        self.window.get_content_area().pack_start(self.infobar, False, True, 0)
+        vbox = gtk.VBox()
+        self.infobar.add(vbox)
+        vbox.show()
+        self.infoTitleLabel = gtk.Label()
+        vbox.pack_start(self.infoTitleLabel, False, True, 0)
+        self.infoTitleLabel.show()
+        self.infoDescriptionLabel = gtk.Label()
+        vbox.pack_start(self.infoDescriptionLabel, False, True, 0);
+        self.infoDescriptionLabel.show()
+
+        self.__gui.connect_signals(self)
+        
         chooser = self.__gui.get_object('filechooser')
         
         try:
@@ -514,12 +546,14 @@ class GtkSaveGameDialog:
         
         # Filter out non PGN files by default
         pgnFilter = gtk.FileFilter()
-        pgnFilter.set_name('PGN files')
+        # Translators: Save Game Dialog: Name of filter to show only PGN files
+        pgnFilter.set_name(_('PGN files'))
         pgnFilter.add_pattern('*.pgn')
         chooser.add_filter(pgnFilter)
         
         allFilter = gtk.FileFilter()
-        allFilter.set_name('All files')
+        # Translators: Save Game Dialog: Name of filter to show all files
+        allFilter.set_name(_('All files'))
         allFilter.add_pattern('*')
         chooser.add_filter(allFilter)
         
@@ -534,9 +568,10 @@ class GtkSaveGameDialog:
         """
         """
         self.firstExpose = True
-        self.__gui.get_object('error_box').show()
-        self.__gui.get_object('error_title_label').set_markup('<big><b>%s</b></big>' % title)
-        self.__gui.get_object('error_description_label').set_markup('<i>%s</i>' % content)
+        self.infobar.set_message_type(gtk.MESSAGE_ERROR)
+        self.infoTitleLabel.set_markup('<big><b>%s</b></big>' % title)
+        self.infoDescriptionLabel.set_markup('<i>%s</i>' % content)
+        self.infobar.show()
         
     def _on_response(self, dialog, responseId):
         """Gtk+ callback"""
@@ -632,10 +667,23 @@ class GtkPreferencesDialog:
             iter = promotionModel.append()
             promotionModel.set(iter, 0, label, 1, key)
             
+        # Make model for piece styles
+        pieceStyleModel = gtk.ListStore(str, str)
+        widget = self.__gui.get_object('piece_style_combo')
+        widget.set_model(pieceStyleModel)
+                     # Translators: a simple piece set will be used in 2d mode
+        view_list = [('simple', _('Simple')),
+                     # Translators: a fancy piece set will be used in 2d mode
+                     ('fancy',  _('Fancy'))]
+        for (key, label) in view_list:
+            iter = pieceStyleModel.append()
+            pieceStyleModel.set(iter, 0, label, 1, key)
+
         # Watch for config changes
-        for key in ['show_3d', 'show_3d_smooth', 'show_toolbar', 'show_history', 
-                    'show_move_hints', 'show_numbering',
-                    'move_format', 'board_view', 'promotion_type']:
+        for key in ['show_3d', 'show_3d_smooth', 'piece_style', 'show_toolbar',
+                    'show_history', 'show_move_hints', 'show_numbering',
+                    'move_format', 'board_view', 'promotion_type',
+                    'show_captured_pieces']:
             glchess.config.watch(key, self.__applyConfig)
             try:
                 value = glchess.config.get(key)
@@ -650,10 +698,20 @@ class GtkPreferencesDialog:
         if name == 'show_3d':
             self.__gui.get_object('show_3d').set_active(value)
             self.__gui.get_object('show_3d_smooth').set_sensitive(value)            
+            self.__gui.get_object('piece_style_combo').set_sensitive(not value)            
 
         elif name == 'show_3d_smooth':
             self.__gui.get_object('show_3d_smooth').set_active(value)
             
+        elif name == 'piece_style':
+            widget = self.__gui.get_object('piece_style_combo')
+            for row in widget.get_model():
+                if row[1] == value:
+                    widget.set_active_iter(row.iter)
+                
+        elif name == 'show_captured_pieces':
+            self.__gui.get_object('show_captured_pieces').set_active(value)
+                
         elif name == 'show_toolbar':
             self.__gui.get_object('show_toolbar').set_active(value)
                 
@@ -703,6 +761,16 @@ class GtkPreferencesDialog:
         self.setVisible(False)
         return True
 
+    def _on_piece_style_combo_changed(self, widget):
+        """Gtk+ callback"""
+        model = widget.get_model()
+        iter = widget.get_active_iter()
+        if iter is None:
+            return
+        data = model.get(iter, 1)
+        if data[0] is not None:
+            glchess.config.set('piece_style', data[0])
+
     def _on_move_format_combo_changed(self, widget):
         """Gtk+ callback"""
         model = widget.get_model()
@@ -739,7 +807,11 @@ class GtkPreferencesDialog:
         
     def _on_3d_smooth_toggled(self, widget):
         """Gtk+ callback"""
-        glchess.config.set('show_3d_smooth', widget.get_active())        
+        glchess.config.set('show_3d_smooth', widget.get_active())
+
+    def _on_show_captured_pieces_activate(self, widget):
+        """Gtk+ callback"""
+        glchess.config.set('show_captured_pieces', widget.get_active())
 
     def _on_show_toolbar_activate(self, widget):
         """Gtk+ callback"""
