@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 __author__ = 'Robert Ancell <bob27@users.sourceforge.net>'
 __license__ = 'GNU General Public License Version 2'
 __copyright__ = 'Copyright 2005-2006  Robert Ancell'
@@ -37,7 +38,7 @@ class GameHistory:
                 try:
                     p = chess.pgn.PGN(fileName, 1)
                 except chess.pgn.Error, e:
-                    print e.message
+                    print str(e)
                 except IOError, e:
                     print e.strerror
                 else:
