@@ -474,22 +474,21 @@ init_preview (void)
 void
 draw_preview (void)
 {
-/*
   guint i;
+  cairo_pattern_t *pattern;
 
   for (i = 0; i < MAXNPIECES; i++) {
 
     if (i < npieces)
-      gdk_window_set_back_pixmap (gtk_widget_get_window (preview_widgets[i]),
-                                  preview_surfaces[preview[i] - 1], FALSE);
+      pattern = cairo_pattern_create_for_surface (preview_surfaces[preview[i] - 1]);
     else
-      gdk_window_set_back_pixmap (gtk_widget_get_window (preview_widgets[i]),
-                                  blank_preview_surface, FALSE);
+      pattern = cairo_pattern_create_for_surface (blank_preview_surface);
 
-    gdk_window_clear (gtk_widget_get_window (preview_widgets[i]));
+    gdk_window_set_background_pattern (gtk_widget_get_window (preview_widgets[i]),
+                                       pattern);
+    cairo_pattern_destroy (pattern);
+    gtk_widget_queue_draw (preview_widgets[i]);
   }
-*/
-
 }
 
 static void
@@ -867,8 +866,8 @@ field_draw_callback (GtkWidget * widget, cairo_t *cr)
   guint i, j, idx;
   GdkColor cursorColor;
 
-  for (i = 0; i < hfieldsize; i++) {
-    for (j = 0; j < vfieldsize; j++) {
+  for (i = 0; i < vfieldsize; i++) {
+    for (j = 0; j < hfieldsize; j++) {
       int phase, color;
 
       idx = j + i * hfieldsize;
@@ -1588,26 +1587,6 @@ quit_cb (EggSMClient *client,
   return FALSE;
 }
 
-#endif /* WITH_SMCLIENT */
-
-static void
-load_properties (void)
-{
-  gchar *buf;
-
-  ball_filename = games_conf_get_string_with_default (KEY_PREFERENCES_GROUP, KEY_BALL_THEME, DEFAULT_BALL_THEME);
-
-  move_timeout = games_conf_get_integer (KEY_PREFERENCES_GROUP, KEY_MOVE_TIMEOUT, NULL);
-  if (move_timeout <= 0)
-    move_timeout = 100;
-
-  buf = games_conf_get_string_with_default (KEY_PREFERENCES_GROUP, KEY_BACKGROUND_COLOR, "#000000"); /* FIXMEchpe? */
-  set_backgnd_color (buf);
-  g_free (buf);
-
-  load_theme ();
-}
-
 static void
 restart (void)
 {
@@ -1639,6 +1618,26 @@ restart (void)
   }
 }
 
+#endif /* WITH_SMCLIENT */
+
+static void
+load_properties (void)
+{
+  gchar *buf;
+
+  ball_filename = games_conf_get_string_with_default (KEY_PREFERENCES_GROUP, KEY_BALL_THEME, DEFAULT_BALL_THEME);
+
+  move_timeout = games_conf_get_integer (KEY_PREFERENCES_GROUP, KEY_MOVE_TIMEOUT, NULL);
+  if (move_timeout <= 0)
+    move_timeout = 100;
+
+  buf = games_conf_get_string_with_default (KEY_PREFERENCES_GROUP, KEY_BACKGROUND_COLOR, "#000000"); /* FIXMEchpe? */
+  set_backgnd_color (buf);
+  g_free (buf);
+
+  load_theme ();
+}
+
 static const GtkActionEntry actions[] = {
   {"GameMenu", NULL, N_("_Game")},
   {"SettingsMenu", NULL, N_("_Settings")},
