@@ -55,7 +55,6 @@ GnibblesWorm *worms[NUMWORMS];
 GnibblesBoni *boni = NULL;
 GnibblesWarpManager *warpmanager;
 
-GdkPixmap *buffer_pixmap = NULL;
 GdkPixbuf *logo_pixmap = NULL;
 
 GdkPixbuf *wall_pixmaps[11] = { NULL, NULL, NULL, NULL, NULL,
@@ -171,6 +170,7 @@ gnibbles_load_pixmap (gint tilesize)
   }
 }
 
+G_GNUC_NORETURN
 void
 gnibbles_error (gchar *message)
 {
