@@ -231,26 +231,26 @@ class UI (gconf_wrapper.GConfWrapper):
             ('Game', None, _('_Game')),
             ('New', gtk.STOCK_NEW, None, '<Control>n', _('New game'), self.new_cb),
             ('Reset', gtk.STOCK_CLEAR, _('_Reset'), '<Control>b',
-             _("Reset current grid(do-over)"), self.game_reset_cb),
+             None, self.game_reset_cb),
             ('Undo', gtk.STOCK_UNDO, _('_Undo'), '<Control>z',
              _('Undo last action'), self.stop_dancer),
             ('Redo', gtk.STOCK_REDO, _('_Redo'), '<Shift><Control>z',
              _('Redo last action')),
             ('PuzzleInfo', gtk.STOCK_ABOUT, _('Puzzle _Statistics...'), None,
-             _('Show statistics about current puzzle'), self.show_info_cb),
-            ('Print', gtk.STOCK_PRINT, _('_Print...'), '<Control>p', _('Print current game'), self.print_game),
+             None, self.show_info_cb),
+            ('Print', gtk.STOCK_PRINT, _('_Print...'), '<Control>p', None, self.print_game),
             ('PrintMany', gtk.STOCK_PRINT, _('Print _Multiple Sudokus...'), None,
-             _('Print more than one sudoku at a time.'), self.print_multiple_games),
-            ('Close', gtk.STOCK_CLOSE, None, '<Control>w', _('Close Sudoku'), self.quit_cb),
+             None, self.print_multiple_games),
+            ('Close', gtk.STOCK_CLOSE, None, '<Control>w', None, self.quit_cb),
             ('Settings', None, _('_Settings')),
             ('FullScreen', gtk.STOCK_FULLSCREEN, None, 'F11', None, self.full_screen_cb),
             ('Tools', None, _('_Tools')),
             ('ShowPossible', gtk.STOCK_DIALOG_INFO, _('_Hint'), '<Control>h',
              _('Show a square that is easy to fill.'), self.show_hint_cb),
             ('ClearTopNotes', None, _('Clear _Top Notes'), '<Control>j',
-             _("Clear all of the top notes"), self.clear_top_notes_cb),
+             None, self.clear_top_notes_cb),
             ('ClearBottomNotes', None, _('Clear _Bottom Notes'), '<Control>k',
-             _("Clear all of the bottom notes"), self.clear_bottom_notes_cb),
+             None, self.clear_bottom_notes_cb),
             ('Help', None, _('_Help'), None, None, None),
             ('ShowHelp', gtk.STOCK_HELP, _('_Contents'), 'F1', None, self.show_help),
             ('About', gtk.STOCK_ABOUT, None, None, None, self.show_about),
@@ -392,12 +392,24 @@ class UI (gconf_wrapper.GConfWrapper):
         self.gconf['difficulty'] = self.gconf['difficulty'] + 0.1
         self.timer.finish_timing()
         self.sudoku_tracker.finish_game(self)
-        if self.timer.active_time != self.timer.total_time:
-            sublabel = _("You completed the puzzle in %(totalTime)s (%(activeTime)s active).") % {'totalTime': self.timer.total_time_string(),
-            'activeTime': self.timer.active_time_string()
-                    }
+        if self.timer.active_time < 60:
+            seconds = int(self.timer.active_time)
+            sublabel = ngettext("You completed the puzzle in %d second",
+                                "You completed the puzzle in %d seconds", seconds) % seconds
+        elif self.timer.active_time < 3600:
+            minutes = int(self.timer.active_time / 60)
+            seconds = int(self.timer.active_time - minutes*60)
+            minute_string = ngettext("%d minute", "%d minutes", minutes) % minutes
+            second_string = ngettext("%d second", "%d seconds", seconds) % seconds
+            sublabel = _("You completed the puzzle in %(minute)s and %(second)s") % {'minute': minute_string, 'second': second_string}
         else:
-            sublabel = _("You completed the puzzle in %(totalTime)s.") % {'totalTime': self.timer.total_time_string()}
+            hours = int(self.timer.active_time / 3600)
+            minutes = int((self.timer.active_time - hours*3600) / 60)
+            seconds = int(self.timer.active_time - hours*3600 - minutes*60)
+            hour_string = ngettext("%d hour", "%d hours", hours) % hours
+            minute_string = ngettext("%d minute", "%d minutes", minutes) % minutes
+            second_string = ngettext("%d second", "%d seconds", seconds) % seconds
+            sublabel = _("You completed the puzzle in %(hour)s, %(minute)s and %(second)s") % {'hour': hour_string, 'minute': minute_string, 'second': second_string}
         sublabel += "\n"
         sublabel += ngettext("You got %(n)s hint.", "You got %(n)s hints.", self.gsd.hints) % {'n':self.gsd.hints}
         sublabel += "\n"
@@ -650,7 +662,13 @@ class UI (gconf_wrapper.GConfWrapper):
         puzzle = self.gsd.grid.virgin.to_string()
         diff = self.sudoku_maker.get_difficulty(puzzle)
         information = _("Calculated difficulty: ")
-        information += diff.value_string()
+        try:
+            information += {'easy': _('Easy'),
+                            'medium': _('Medium'),
+                            'hard': _('Hard'),
+                            'very hard': _('Very Hard')}[diff.value_category()]
+        except KeyError:
+            information += diff.value_category()
         information += " (%1.2f)" % diff.value
         information += "\n"
         information += _("Number of moves instantly fillable by elimination: ")
