@@ -674,7 +674,6 @@ properties_callback (void)
 					     GTK_RESPONSE_CLOSE, NULL);
   gtk_container_set_border_width (GTK_CONTAINER (pref_dialog), 5);
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (pref_dialog))), 2);
-  gtk_dialog_set_has_separator (GTK_DIALOG (pref_dialog), FALSE);
   gtk_window_set_resizable (GTK_WINDOW (pref_dialog), FALSE);
   gtk_dialog_set_default_response (GTK_DIALOG (pref_dialog),
 				   GTK_RESPONSE_CLOSE);
@@ -899,11 +898,7 @@ about_callback (void)
   gchar *license = games_get_license (_("Mahjongg"));
 
   gtk_show_about_dialog (GTK_WINDOW (window),
-#if GTK_CHECK_VERSION (2, 11, 0)
                          "program-name", _("Mahjongg"),
-#else
-                         "name", _("Mahjongg"),
-#endif
 			 "version", VERSION,
 			 "comments",
 			 _("A matching game played with Mahjongg tiles.\n\nMahjongg is a part of GNOME Games."),
@@ -1354,10 +1349,7 @@ main (int argc, char *argv[])
 #endif
 
   context = g_option_context_new (NULL);
-#if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-#endif
-
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
@@ -1428,7 +1420,6 @@ main (int argc, char *argv[])
   ui_manager = gtk_ui_manager_new ();
 
   games_stock_prepare_for_statusbar_tooltips (ui_manager, statusbar);
-  gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (statusbar), FALSE);
 
   create_menus (ui_manager);
   accel_group = gtk_ui_manager_get_accel_group (ui_manager);  
